@@ -1,6 +1,6 @@
 import sqlite3
 import os
-from importlib import resources
+#from importlib import resources
 
 
 __db=""
